@@ -1,8 +1,9 @@
 __all__ = ['is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'to_isbn10', 'to_isbn13', 'get_isbnlike', 'notisbn',
-           'canonical', 'get_canonical_isbn', 'editions', 'isbn_from_words', 'quiet_errors']
+           'canonical', 'get_canonical_isbn', 'editions', 'isbn_from_words',
+           'quiet_errors']
 
-__version__ = '2.0.6'
+__version__ = '2.0.7'
 
 from .exceptions import quiet_errors
 from .core import (is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,
